/**
 * @constructor Apemandocker
 * @param {object} config
 */
"use strict";

const execcli = require('execcli'),
    argx = require('argx'),
    extend = require('extend');

/** @lends Apemandocker */
function Apemandocker(config) {
    let s = this;
    extend(s, config || {});
}

Apemandocker.prototype = {
    _docker: function (args, callback) {
        execcli('docker', args, {
            notfound: `install docker from https://docs.docker.com`
        }, callback);
    },
    /**
     * Build docker source.
     * @param {string} source - Name of source.
     * @param {object} [options] - Optional settings.
     * @param {function} callback - Callback when done.
     */
    buildImage: function (source, options, callback) {
        let s = this;
        let args = argx(arguments);
        callback = args.pop('function') || argx.noop;
        options = args.pop('object') || {};
        s._docker(['build', options, source], callback);
    },
    /**
     * Remove docker image.
     * @param {string} image - Name of image.
     * @param {object} [options] - Optional settings.
     * @param {function} callback - Callback when done.
     */
    removeImage: function (image, options, callback) {
        let s = this;
        let args = argx(arguments);
        callback = args.pop('function') || argx.noop;
        options = args.pop('object') || {};
        s._docker(['rmi', options, image], callback);
    }
};

module.exports = Apemandocker;
